from sqlalchemy import insert, select
from sqlalchemy.ext.asyncio.session import AsyncSession

from ..models import UserModel
from ..schemas import UserDBDTO, UserReadDTO


class UserRepository:
    def __init__(self, session: AsyncSession):
        self.session = session

    async def add_one(
        self,
        data: UserDBDTO,
    ) -> UserReadDTO:
        stmt = insert(UserModel).values(**data.model_dump()).returning(UserModel)
        res = await self.session.execute(stmt)
        return UserReadDTO.model_validate(res.scalar_one())

    async def find_one(self, filter: dict) -> UserReadDTO | None:
        stmt = select(UserModel).filter_by(**filter)
        res = await self.session.execute(stmt)
        res = res.scalar_one_or_none()

        if res is not None:
            return UserReadDTO.model_validate(res)
        return None
