from fastapi import APIRouter, Depends

from ..di import get_user_service
from ..schemas import RefReadDTO, UserAuthDTO, UserDTO, UserReadDTO
from ..services import UserService, get_current_user

router = APIRouter(
    prefix="/user",
)


@router.get("/me", response_model=UserReadDTO, tags=["user"])
async def get_user(
    user_service: UserService = Depends(get_user_service),
    user: UserDTO = Depends(get_current_user),
) -> UserReadDTO | None:
    return await user_service.get_user(email=user.email)


@router.get("/me/create_ref", status_code=201, response_model=RefReadDTO)
async def create_refer_code(
    user_service: UserService = Depends(get_user_service),
    user: UserAuthDTO = Depends(get_current_user),
):
    res = await user_service.create_ref(user=user)

    return res
