from passlib.context import CryptContext

from ..schemas import UserAuthDTO, UserDBDTO, UserWriteDTO
from ..uow import UnitOfWork


class UserService:
    def __init__(self, uow: UnitOfWork):
        self.uow = uow
        self.crypto_context = CryptContext(schemes="bcrypt")

    async def add_one(self, data: UserWriteDTO):
        new_data = data.model_dump()
        new_data["hashed_password"] = self.crypto_context.hash(new_data.pop("password"))
        dataf: UserDBDTO = UserDBDTO(**new_data)
        async with self.uow:
            res = await self.uow.users.add_one(data=dataf)
        return res

    async def get_user(self, email: str):
        async with self.uow:
            user = await self.uow.users.find_one(filter={"email": email})
        return user

    async def create_ref(self, user: UserAuthDTO):
        async with self.uow:
            res = await self.uow.ref.add_ref(user=user)
        return res
